@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008 Julien Danjou
--- @release v3.5.1
+-- @release v3.5.2
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -220,7 +220,10 @@ function client.tiled(screen)
     local tclients = {}
     -- Remove floating clients
     for k, c in pairs(clients) do
-        if not client.floating.get(c) then
+        if not client.floating.get(c)
+            and not c.fullscreen
+            and not c.maximized_vertical
+            and not c.maximized_horizontal then
             table.insert(tclients, c)
         end
     end
