@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008 Julien Danjou
--- @release v3.5.1
+-- @release v3.5.2
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -154,6 +154,7 @@ function tag.delete(target_tag, fallback_tag)
 
     -- delete the tag
     data.tags[target_tag].screen = nil
+    target_tag.activated = false
 
     -- If no tags are visible, try and view one.
     if tag.selected(target_scr) == nil and ntags > 0 then
@@ -466,7 +467,8 @@ end
 -- @param tags A table with tags to view only.
 -- @param screen Optional screen number of the tags.
 function tag.viewmore(tags, screen)
-    local screen_tags = tag.gettags(screen or capi.mouse.screen)
+    local screen = screen or capi.mouse.screen
+    local screen_tags = tag.gettags(screen)
     for _, _tag in ipairs(screen_tags) do
         if not util.table.hasitem(tags, _tag) then
             _tag.selected = false
@@ -518,20 +520,17 @@ end
 
 --- Tag a client with the set of current tags.
 -- @param c The client to tag.
--- @param startup Optional: don't do anything if true.
-function tag.withcurrent(c, startup)
-    if startup ~= true then
-        local tags = {}
-        for k, t in ipairs(c:tags()) do
-            if tag.getscreen(t) == c.screen then
-                table.insert(tags, t)
-            end
+function tag.withcurrent(c)
+    local tags = {}
+    for k, t in ipairs(c:tags()) do
+        if tag.getscreen(t) == c.screen then
+            table.insert(tags, t)
         end
-        if #tags == 0 then
-            tags = tag.selectedlist(c.screen)
-        end
-        c:tags(tags)
     end
+    if #tags == 0 then
+        tags = tag.selectedlist(c.screen)
+    end
+    c:tags(tags)
 end
 
 local function attached_connect_signal_screen(screen, sig, func)
