@@ -10,13 +10,14 @@ theme.bg_normal     = "#222222"
 theme.bg_focus      = "#535d6c"
 theme.bg_urgent     = "#ff0000"
 theme.bg_minimize   = "#444444"
+theme.bg_systray    = theme.bg_normal
 
 theme.fg_normal     = "#aaaaaa"
 theme.fg_focus      = "#ffffff"
 theme.fg_urgent     = "#ffffff"
 theme.fg_minimize   = "#ffffff"
 
-theme.border_width  = "1"
+theme.border_width  = 1
 theme.border_normal = "#000000"
 theme.border_focus  = "#535d6c"
 theme.border_marked = "#91231c"
@@ -35,14 +36,12 @@ theme.border_marked = "#91231c"
 theme.taglist_squares_sel   = "/usr/local/share/awesome/themes/default/taglist/squarefw.png"
 theme.taglist_squares_unsel = "/usr/local/share/awesome/themes/default/taglist/squarew.png"
 
-theme.tasklist_floating_icon = "/usr/local/share/awesome/themes/default/tasklist/floatingw.png"
-
 -- Variables set for theming the menu:
 -- menu_[bg|fg]_[normal|focus]
 -- menu_[border_color|border_width]
 theme.menu_submenu_icon = "/usr/local/share/awesome/themes/default/submenu.png"
-theme.menu_height = "15"
-theme.menu_width  = "100"
+theme.menu_height = 15
+theme.menu_width  = 100
 
 -- You can add as many variables as
 -- you wish and access them by using
@@ -73,8 +72,7 @@ theme.titlebar_maximized_button_focus_inactive  = "/usr/local/share/awesome/them
 theme.titlebar_maximized_button_normal_active = "/usr/local/share/awesome/themes/default/titlebar/maximized_normal_active.png"
 theme.titlebar_maximized_button_focus_active  = "/usr/local/share/awesome/themes/default/titlebar/maximized_focus_active.png"
 
--- You can use your own command to set your wallpaper
-theme.wallpaper_cmd = { "awsetbg /usr/local/share/awesome/themes/default/background.png" }
+theme.wallpaper = "/usr/local/share/awesome/themes/default/background.png"
 
 -- You can use your own layout icons like this:
 theme.layout_fairh = "/usr/local/share/awesome/themes/default/layouts/fairhw.png"
@@ -92,5 +90,9 @@ theme.layout_dwindle = "/usr/local/share/awesome/themes/default/layouts/dwindlew
 
 theme.awesome_icon = "/usr/local/share/awesome/icons/awesome16.png"
 
+-- Define the icon theme for application icons. If not set then the icons 
+-- from /usr/local/share/icons and /usr/local/share/icons/hicolor will be used.
+theme.icon_theme = nil
+
 return theme
 -- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:textwidth=80
